### 0.10.11 {small}`2024-11-12`

```{rubric} Features
```
* Adds `trim` to `pp.bbknn` to restrict the `connectivities` {pr}`285` {smaller}`S Dicks & P Angerer`
```{rubric} Performance
```
* make `trim` for `pp.bbknn` even faster without needing to transpose {pr}`290` {smaller}`S Dicks`


```{rubric} Misc
```
* Adds support for `Numpy-2.0` {pr}`277` {smaller}`S Dicks`
* Adds support for `rapids-24.10` {pr}`277` {smaller}`S Dicks`
* Updates testing to use `rapids-24.10` {pr}`277` {smaller}`S Dicks`
* Updates `docker` image to use `rapids-24.10` {pr}`277` {smaller}`S Dicks`
* `tl.UMAP` now uses `simplicial_set_embedding` for `rapids>=24.10` {pr}`278` {smaller}`S Dicks`
* Updates `docker` image to use the default `ENTRYPOINT` {pr}`292` {smaller}`N Trummer`
